Learn R Programming

shinySbm (version 0.2.0)

shinySbm-package: shinySbm: 'shiny' Application to Use the Stochastic Block Model

Description

A 'shiny' interface for a simpler use of the 'sbm' R package. It also contains useful functions to easily explore the 'sbm' package results. With this package you should be able to use the stochastic block model without any knowledge in R, get automatic reports and nice visuals, as well as learning the basic functions of 'sbm'.

Arguments

Author

Maintainer: Julie Aubert julie.aubert@inrae.fr (ORCID)

Authors:

Other contributors:

  • großBM team [contributor]

  • INRAE (ROR) [copyright holder]

See Also