A 'shiny' interface for a simpler use of the 'sbm' R package. It also contains useful functions to easily explore the 'sbm' package results. With this package you should be able to use the stochastic block model without any knowledge in R, get automatic reports and nice visuals, as well as learning the basic functions of 'sbm'.
Maintainer: Julie Aubert julie.aubert@inrae.fr (ORCID)
Authors:
Theodore Vanrenterghem shiny.sbm.dev@gmail.com
Saint-Clair Chabert-Liddell (ORCID)
Other contributors:
großBM team [contributor]
INRAE (ROR) [copyright holder]